@@ -1,11 +1,14 @@
 
+from . import base
 from . import calc
+from . import config
 from . import constants
 from . import link_db
-from . import ms_prediction
+from . import metric
+from . import ms_pred
 from . import post_analysis
 from . import rapid_kit
-from . import seq_process
+from . import sequence
 from . import stats
 
 from .inherited_builtins import *
