@@ -1,7 +1,5 @@
-
 from ._library import SpectronautLibrary
-
-from . import sn_constant
-from .basic_operations import *
+from . import basic_operations
 from . import mod_process
 from . import result_process
+from . import sn_constant
